@@ -1,13 +1,13 @@
 /**
  *  @File     binfileimplclient.h
  *
- *  @Author   Lukas Zeller (luz@synthesis.ch)
+ *  @Author   Lukas Zeller (luz@plan44.ch)
  *
  *  @brief TBinfileImplClient
  *    Represents a client session (agent) that saves profile, target, resume info
  *    and optionally changelog in TBinFile binary files
  *
- *    Copyright (c) 2003-2009 by Synthesis AG (www.synthesis.ch)
+ *    Copyright (c) 2003-2011 by Synthesis AG + plan44.ch
  *
  *  @Date 2005-09-30 : luz : created from TBinfileImplClient
  */
@@ -23,9 +23,10 @@
 #include "stdlogicagent.h"
 #include "binfileimplds.h"
 #include "engineinterface.h"
+#include "syncclientbase.h"
 
 #ifndef SYSYNC_CLIENT
-  #error "binfileimplclient is CLIENT-ONLY!"
+  #error "binfileimplclient only makes sense with client datastores"
 #endif
 
 namespace sysync {
@@ -37,7 +38,7 @@ namespace sysync {
 #ifdef ENGINEINTERFACE_SUPPORT
 
 // forward
-class TBinfileClientRootKey;
+class TBinfileAgentRootKey;
 class TBinfileClientConfig;
 
 // Engine module class
@@ -333,33 +334,22 @@ private:
 
 
 // Binfile based client settings rootkey
-class TBinfileClientRootKey :
+class TBinfileAgentRootKey :
   public TSettingsRootKey
 {
   typedef TSettingsRootKey inherited;
 
 public:
-  TBinfileClientRootKey(TEngineInterface *aEngineInterfaceP) :
-    inherited(aEngineInterfaceP) {};
+  TBinfileAgentRootKey(TEngineInterface *aEngineInterfaceP);
 
 protected:
   // open subkey by name (not by path!)
-  // - this is the actual implementation
   virtual TSyError OpenSubKeyByName(
     TSettingsKeyImpl *&aSettingsKeyP,
     cAppCharP aName, stringSize aNameSize,
     uInt16 aMode
-  ) {
-    if (strucmp(aName,"profiles",aNameSize)==0)
-      aSettingsKeyP = new TBinfileProfilesKey(fEngineInterfaceP);
-    else if (strucmp(aName,"synclogs",aNameSize)==0)
-      aSettingsKeyP = new TBinfileLogsKey(fEngineInterfaceP);
-    else
-      return inherited::OpenSubKeyByName(aSettingsKeyP,aName,aNameSize,aMode);
-    // opened a key
-    return LOCERR_OK;
-  };
-}; // TBinfileClientRootKey
+  );
+}; // TBinfileAgentRootKey
 
 
 
@@ -370,9 +360,9 @@ protected:
 // ======
 
 class TBinfileClientConfig:
-  public TClientConfig
+  public TAgentConfig
 {
-  typedef TClientConfig inherited;
+  typedef TAgentConfig inherited;
 public:
   TBinfileClientConfig(TConfigElement *aParentElement);
   virtual ~TBinfileClientConfig();
@@ -468,6 +458,10 @@ public:
   );
   // - get path where to store binfiles
   void getBinFilesPath(string &aPath);
+  // activtion switch (for making it inactive e.g. in server case)
+  bool fBinfilesActive;
+  // separate changelogs per profile
+  bool fSeparateChangelogs;
   #ifndef HARDCODED_CONFIG
   // - configurable path where to store binfiles
   string fBinFilesPath;
@@ -477,9 +471,11 @@ public:
   // Binary Files
   TBinFile fProfileBinFile;
   TBinFile fTargetsBinFile;
-	// -  cleanup
-	void cleanChangeLogForTarget(sInt32 aTargetIndex);
-	void cleanChangeLogForDBname(cAppCharP aDBName);
+	// -  cleanup changelog, pendingmap, pendingitem
+  string relatedDBNameBase(cAppCharP aDBName, sInt32 aProfileID);
+	void cleanChangeLogForTarget(sInt32 aTargetIndex, sInt32 aProfileID);
+	void cleanChangeLogForDBname(cAppCharP aDBName, sInt32 aProfileID);
+	void separateChangeLogsAndRelated(cAppCharP aDBName);
   // - called when app should save its persistent state
   virtual void saveAppState(void);
   // - MUST be called after creating config to load (or pre-load) variable parts of config
@@ -490,6 +486,9 @@ public:
   // open and close the settings databases
   localstatus openSettingsDatabases(bool aDoLoose);
   void closeSettingsDatabases(void);
+private:
+	// helper for migrating to separated changelogs/pendingmaps/pendingitem
+	void separateDBFile(cAppCharP aDBName, cAppCharP aDBSuffix, sInt32 aProfileID);
 protected:
   // check config elements
   #ifndef HARDCODED_CONFIG
@@ -509,10 +508,12 @@ class TBinfileImplClient: public TStdLogicAgent
 {
   typedef TStdLogicAgent inherited;
   #ifdef ENGINEINTERFACE_SUPPORT
-  friend class TBinFileClientParamsKey;
+  friend class TBinFileAgentParamsKey;
   #endif
 public:
-  TBinfileImplClient(TSyncClientBase *aSyncClientBaseP, const char *aSessionID);
+  TBinfileImplClient(TSyncAppBase *aSyncAppBaseP, TSyncSessionHandle *aSyncSessionHandleP, cAppCharP aSessionID);
+  /// check if active derived classes (in particular: customImplDS that CAN derive binfiles, but does not necessarily so)
+  bool binfilesActive(void) { return fConfigP && fConfigP->fBinfilesActive; };
   // - selects a profile (returns false if profile not found)
   //   Note: This call must create and initialize all datastores that
   //         are to be synced with that profile.
@@ -549,7 +550,7 @@ public:
   uInt32 fRemotepartyID;
   // - check remote devinf to detect special behaviour needed for some servers. Base class
   //   does not do anything on server level (configured rules are handled at session level)
-  virtual localstatus checkRemoteSpecifics(SmlDevInfDevInfPtr_t aDevInfP);
+  virtual localstatus checkRemoteSpecifics(SmlDevInfDevInfPtr_t aDevInfP, SmlDevInfDevInfPtr_t *aOverrideDevInfP);
   TBinfileDBSyncProfile fProfile;
   // - remote specific client behaviour flags
   uInt8 fRemoteFlags; // flags for remote specific behaviour (remotespecs_XXX)
@@ -566,24 +567,23 @@ private:
 // =========================================
 
 // client runtime parameters
-class TBinFileClientParamsKey :
-  public TClientParamsKey
+class TBinFileAgentParamsKey :
+  public TAgentParamsKey
 {
-  typedef TClientParamsKey inherited;
+  typedef TAgentParamsKey inherited;
 
 public:
-  TBinFileClientParamsKey(TEngineInterface *aEngineInterfaceP, TSyncClient *aClientSessionP);
-  virtual ~TBinFileClientParamsKey() {};
+  TBinFileAgentParamsKey(TEngineInterface *aEngineInterfaceP, TSyncAgent *aClientSessionP);
+  virtual ~TBinFileAgentParamsKey() {};
 
 protected:
   // open subkey by name (not by path!)
-  // - this is the actual implementation
   virtual TSyError OpenSubKeyByName(
     TSettingsKeyImpl *&aSettingsKeyP,
     cAppCharP aName, stringSize aNameSize,
     uInt16 aMode
   );
-}; // TBinFileClientParamsKey
+}; // TBinFileAgentParamsKey
 
 
 #endif // ENGINEINTERFACE_SUPPORT
