@@ -25,6 +25,22 @@ static std::string SubIDName(const std::string &subid)
     return subid.empty() ? "<master>" : subid;
 }
 
+/** remove X-SYNCEVOLUTION-EXDATE-DETACHED from VEVENT */
+static void removeSyncEvolutionExdateDetached(icalcomponent *parent)
+{
+    icalproperty *prop = icalcomponent_get_first_property(parent, ICAL_ANY_PROPERTY);
+    while (prop) {
+        icalproperty *next = icalcomponent_get_next_property(parent, ICAL_ANY_PROPERTY);
+        const char *xname = icalproperty_get_x_name(prop);
+        if (xname &&
+            !strcmp(xname, "X-SYNCEVOLUTION-EXDATE-DETACHED")) {
+            icalcomponent_remove_property(parent, prop);
+            icalproperty_free(prop);
+        }
+        prop = next;
+    }
+}
+
 CalDAVSource::CalDAVSource(const SyncSourceParams &params,
                            const boost::shared_ptr<Neon::Settings> &settings) :
     WebDAVSource(params, settings)
@@ -328,6 +344,10 @@ SubSyncSource::SubItemResult CalDAVSource::insertSubItem(const std::string &luid
          comp = icalcomponent_get_next_component(newEvent->m_calendar, ICAL_VEVENT_COMPONENT)) {
         std::string subid = Event::getSubID(comp);
         EventCache::iterator it;
+        // remove X-SYNCEVOLUTION-EXDATE-DETACHED, could be added by
+        // the engine's read/modify/write cycle when resolving a
+        // conflict
+        removeSyncEvolutionExdateDetached(comp);
         if (!luid.empty() &&
             (it = m_cache.find(luid)) != m_cache.end()) {
             // Additional sanity check: ensure that the expected UID is set.
@@ -498,10 +518,55 @@ SubSyncSource::SubItemResult CalDAVSource::insertSubItem(const std::string &luid
             }
         }
     } else {
-        if (subid != knownSubID) {
-            SE_THROW("new CalDAV item does not have right RECURRENCE-ID");
+        if (!subid.empty() && subid != knownSubID) {
+            SE_THROW(StringPrintf("new CalDAV item does not have right RECURRENCE-ID: item %s != expected %s",
+                                  subid.c_str(), knownSubID.c_str()));
         }
         Event &event = loadItem(davLUID);
+
+        if (subid.empty() && subid != knownSubID) {
+            // fix incomplete iCalendar 2.0 item: should have had a RECURRENCE-ID
+            icalcomponent *newcomp =
+                icalcomponent_get_first_component(newEvent->m_calendar, ICAL_VEVENT_COMPONENT);
+            icalproperty *prop = icalcomponent_get_first_property(newcomp, ICAL_RECURRENCEID_PROPERTY);
+            if (prop) {
+                icalcomponent_remove_property(newcomp, prop);
+                icalproperty_free(prop);
+            }
+
+            // reconstruct RECURRENCE-ID with known value and TZID from start time of
+            // the parent event or (if not found) the current event
+            eptr<icalproperty> rid(icalproperty_new_recurrenceid(icaltime_from_string(knownSubID.c_str())),
+                                   "new rid");
+            icalproperty *dtstart = NULL;
+            icalcomponent *comp;
+            // look for parent first
+            for (comp = icalcomponent_get_first_component(event.m_calendar, ICAL_VEVENT_COMPONENT);
+                 comp && !dtstart;
+                 comp = icalcomponent_get_next_component(event.m_calendar, ICAL_VEVENT_COMPONENT)) {
+                if (!icalcomponent_get_first_property(comp, ICAL_RECURRENCEID_PROPERTY)) {
+                    dtstart = icalcomponent_get_first_property(comp, ICAL_DTSTART_PROPERTY);
+                }
+            }
+            // fall back to current event
+            if (!dtstart) {
+                dtstart = icalcomponent_get_first_property(newcomp, ICAL_DTSTART_PROPERTY);
+            }
+            // ignore missing TZID
+            if (dtstart) {
+                icalparameter *tzid = icalproperty_get_first_parameter(dtstart, ICAL_TZID_PARAMETER);
+                if (tzid) {
+                    icalproperty_set_parameter(rid, icalparameter_new_clone(tzid));
+                }
+            }
+
+            // finally add RECURRENCE-ID and fix newEvent's meta information
+            icalcomponent_add_property(newcomp, rid.release());
+            subid = knownSubID;
+            newEvent->m_subids.erase("");
+            newEvent->m_subids.insert(subid);
+        }
+
         // no changes expected yet, copy previous attributes
         subres.m_mainid = davLUID;
         subres.m_uid = event.m_UID;
@@ -691,19 +756,57 @@ void CalDAVSource::readSubItem(const std::string &davLUID, const std::string &su
             icalcomponent_add_component(calendar, clone.release());
         }
         bool found = false;
+        icalcomponent *parent = NULL;
         for (icalcomponent *comp = icalcomponent_get_first_component(event.m_calendar, ICAL_VEVENT_COMPONENT);
              comp;
              comp = icalcomponent_get_next_component(event.m_calendar, ICAL_VEVENT_COMPONENT)) {
             if (Event::getSubID(comp) == subid) {
                 eptr<icalcomponent> clone(icalcomponent_new_clone(comp), "VEVENT");
+                if (subid.empty()) {
+                    parent = clone.get();
+                }
                 icalcomponent_add_component(calendar, clone.release());
                 found = true;
                 break;
             }
         }
+
         if (!found) {
             SE_THROW("event not found");
         }
+
+        // tell engine and peers about EXDATEs implied by
+        // RECURRENCE-IDs in detached recurrences by creating
+        // X-SYNCEVOLUTION-EXDATE-DETACHED in the parent
+        if (parent && event.m_subids.size() > 1) {
+            // remove all old X-SYNCEVOLUTION-EXDATE-DETACHED (just in case)
+            removeSyncEvolutionExdateDetached(parent);
+
+            // now populate with RECURRENCE-IDs of detached recurrences
+            for (icalcomponent *comp = icalcomponent_get_first_component(event.m_calendar, ICAL_VEVENT_COMPONENT);
+                 comp;
+                 comp = icalcomponent_get_next_component(event.m_calendar, ICAL_VEVENT_COMPONENT)) {
+                icalproperty *prop = icalcomponent_get_first_property(comp, ICAL_RECURRENCEID_PROPERTY);
+                if (prop) {
+                    eptr<char> rid(ical_strdup(icalproperty_get_value_as_string(prop)));
+                    icalproperty *exdate = icalproperty_new_from_string(StringPrintf("X-SYNCEVOLUTION-EXDATE-DETACHED:%s", rid.get()).c_str());
+                    if (exdate) {
+                        icalparameter *tzid = icalproperty_get_first_parameter(prop, ICAL_TZID_PARAMETER);
+                        if (tzid) {
+                            icalproperty_add_parameter(exdate, icalparameter_new_clone(tzid));
+                        }
+#if 0
+                        // not needed
+                        if (icalproperty_get_recurrenceid(exdate).is_date) {
+                            icalproperty_add_parameter(exdate, icalparameter_new_value(ICAL_VALUE_DATE));
+                        }
+#endif
+                        icalcomponent_add_property(parent, exdate);
+                    }
+                }
+            }
+        }
+
         eptr<char> icalstr(ical_strdup(icalcomponent_as_ical_string(calendar)));
         item = icalstr.get();
     }
@@ -1051,6 +1154,7 @@ void CalDAVSource::Event::fixIncomingCalendar(icalcomponent *calendar)
     // time.
     bool ridInUTC = false;
     const icaltimezone *zone = NULL;
+    icalcomponent *parent = NULL;
 
     for (icalcomponent *comp = icalcomponent_get_first_component(calendar, ICAL_VEVENT_COMPONENT);
          comp;
@@ -1064,6 +1168,7 @@ void CalDAVSource::Event::fixIncomingCalendar(icalcomponent *calendar)
         // is parent event? -> remember time zone unless it is UTC
         static const struct icaltimetype null = { 0 };
         if (!memcmp(&rid, &null, sizeof(null))) {
+            parent = comp;
             struct icaltimetype dtstart = icalcomponent_get_dtstart(comp);
             if (!icaltime_is_utc(dtstart)) {
                 zone = icaltime_get_timezone(dtstart);
